@@ -5,6 +5,7 @@ of an object and its parent classes.
 
 from __future__ import unicode_literals
 
+
 def all_bases(c):
 	"""
 	return a tuple of all base classes the class c has as a parent.
@@ -13,6 +14,7 @@ def all_bases(c):
 	"""
 	return c.mro()[1:]
 
+
 def all_classes(c):
 	"""
 	return a tuple of all classes to which c belongs
@@ -21,7 +23,10 @@ def all_classes(c):
 	"""
 	return c.mro()
 
-# borrowed from http://code.activestate.com/recipes/576949-find-all-subclasses-of-a-given-class/
+# borrowed from
+# http://code.activestate.com/recipes/576949-find-all-subclasses-of-a-given-class/
+
+
 def iter_subclasses(cls, _seen=None):
 	"""
 	Generator over all subclasses of a given class, in depth-first order.
@@ -51,9 +56,12 @@ def iter_subclasses(cls, _seen=None):
 	"""
 
 	if not isinstance(cls, type):
-		raise TypeError('iter_subclasses must be called with '
-			'new-style classes, not %.100r' % cls)
-	if _seen is None: _seen = set()
+		raise TypeError(
+			'iter_subclasses must be called with '
+			'new-style classes, not %.100r' % cls
+		)
+	if _seen is None:
+		_seen = set()
 	try:
 		subs = cls.__subclasses__()
 	except TypeError:  # fails only when cls is type
